==> pam_flutter-2.0.1.tar.gz: lib/api/push_notification_api.dart <==
import 'package:http/http.dart' as http;
import 'package:http/http.dart' show Response;
import '../response/pam_push_message.dart';
import '../pam.dart';
import 'package:flutter/foundation.dart';
import 'package:pam_flutter/pam.dart';
import 'dart:convert';

class PamPushNotificationAPI {
  String baseURL;

  PamPushNotificationAPI(this.baseURL);

  Future<List<PamPushMessage>?> read(String? pixel) async {
    if (pixel != null) {
      var uri = Uri.parse(pixel);
      await http.get(uri);
    }
  }

  Future<List<PamPushMessage>?> loadPushNotificationsFromMobile(
      String mobileNumber) async {
    Response? response;
    var db = Pam.shared.getDatabaseAlias();
    var contact = Pam.shared.getContactID();
    try {
      var uri = Uri.parse(
          "$baseURL/api/app-notifications/?_database=$db&_contact_id=$contact&sms=$mobileNumber");
      response = await http.get(uri);
      if (Pam.shared.isEnableLog) {
        debugPrint("🦄🦄🦄🦄🦄 PAM LOAD PUSH NOTIFICATION 🦄🦄🦄🦄🦄🦄\n\n");
        debugPrint(uri.toString());
        debugPrint("mobile number = $mobileNumber");
        debugPrint("🚥🚥🚥🚥🚥 RESULT 🚥🚥🚥🚥🚥");
        debugPrint("Status Code: ${response.statusCode}");
        debugPrint("----- Response Body -----");
        debugPrint(utf8.decode(response.bodyBytes));
        debugPrint("\n\n🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄");
      }
    } catch (e) {
      if (Pam.shared.isEnableLog) {
        debugPrint("\n\n🦄🦄🦄🦄🦄 ERROR 🦄🦄🦄🦄🦄🦄");
        debugPrint(e.toString());
      }
    }

    if (response != null) {
      return PamPushMessage.parse(utf8.decode(response.bodyBytes));
    }

    return null;
  }

  Future<List<PamPushMessage>?> loadPushNotificationsFromEmail(
      String email) async {
    Response? response;
    var db = Pam.shared.getDatabaseAlias();
    var contact = Pam.shared.getContactID();
    try {
      var uri = Uri.parse(
          "$baseURL/api/app-notifications/?_database=$db&_contact_id=$contact&email=$email");
      response = await http.get(uri);
      if (Pam.shared.isEnableLog) {
        debugPrint("🦄🦄🦄🦄🦄 PAM LOAD PUSH NOTIFICATION 🦄🦄🦄🦄🦄🦄\n\n");
        debugPrint(uri.toString());
        debugPrint("email = $email");
        debugPrint("🚥🚥🚥🚥🚥 RESULT 🚥🚥🚥🚥🚥");
        debugPrint("Status Code: ${response.statusCode}");
        debugPrint("----- Response Body -----");
        debugPrint(utf8.decode(response.bodyBytes));
        debugPrint("\n\n🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄");
      }
    } catch (e) {
      if (Pam.shared.isEnableLog) {
        debugPrint("\n\n🦄🦄🦄🦄🦄 ERROR 🦄🦄🦄🦄🦄🦄");
        debugPrint(e.toString());
      }
    }

    if (response != null) {
      return PamPushMessage.parse(utf8.decode(response.bodyBytes));
    }

    return null;
  }

  Future<List<PamPushMessage>?> loadPushNotificationsFromCustomerID(
      String customer) async {
    Response? response;
    var db = Pam.shared.getDatabaseAlias();
    var contact = await Pam.shared.getContactID();
    try {
      var uri = Uri.parse(
          "$baseURL/api/app-notifications?_database=$db&_contact_id=$contact&customer=$customer");
      response = await http.get(uri);
      if (Pam.shared.isEnableLog) {
        debugPrint("🦄🦄🦄🦄🦄 PAM LOAD PUSH NOTIFICATION 🦄🦄🦄🦄🦄🦄\n\n");
        debugPrint(uri.toString());
        debugPrint("customer id = $customer");
        debugPrint("🚥🚥🚥🚥🚥 RESULT 🚥🚥🚥🚥🚥");
        debugPrint("Status Code: ${response.statusCode}");
        debugPrint("----- Response Body -----");
        debugPrint(utf8.decode(response.bodyBytes));
        debugPrint("\n\n🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄");
      }
    } catch (e) {
      if (Pam.shared.isEnableLog) {
        debugPrint("\n\n🦄🦄🦄🦄🦄 ERROR 🦄🦄🦄🦄🦄🦄");
        debugPrint(e.toString());
      }
    }

    if (response != null) {
      return PamPushMessage.parse(utf8.decode(response.bodyBytes));
    }

    return null;
  }
}

==> pam_flutter-2.0.2.tar.gz: lib/api/push_notification_api.dart <==
import 'package:http/http.dart' as http;
import 'package:http/http.dart' show Response;
import '../response/pam_push_message.dart';
import '../pam.dart';
import 'package:flutter/foundation.dart';
import 'package:pam_flutter/pam.dart';
import 'dart:convert';

class PamPushNotificationAPI {
  String baseURL;

  PamPushNotificationAPI(this.baseURL);

  Future<List<PamPushMessage>?> read(String? pixel) async {
    if (pixel != null) {
      var uri = Uri.parse(pixel);
      await http.get(uri);
    }
  }

  Future<List<PamPushMessage>?> loadPushNotificationsFromMobile(
      String mobileNumber) async {
    Response? response;
    var db = Pam.shared.getDatabaseAlias();
    var contact = Pam.shared.getContactID();
    try {
      var uri = Uri.parse(
          "$baseURL/api/app-notifications?_database=$db&_contact_id=$contact&sms=$mobileNumber");
      response = await http.get(uri);
      if (Pam.shared.isEnableLog) {
        debugPrint("🦄🦄🦄🦄🦄 PAM LOAD PUSH NOTIFICATION 🦄🦄🦄🦄🦄🦄\n\n");
        debugPrint(uri.toString());
        debugPrint("mobile number = $mobileNumber");
        debugPrint("🚥🚥🚥🚥🚥 RESULT 🚥🚥🚥🚥🚥");
        debugPrint("Status Code: ${response.statusCode}");
        debugPrint("----- Response Body -----");
        debugPrint(utf8.decode(response.bodyBytes));
        debugPrint("\n\n🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄");
      }
    } catch (e) {
      if (Pam.shared.isEnableLog) {
        debugPrint("\n\n🦄🦄🦄🦄🦄 ERROR 🦄🦄🦄🦄🦄🦄");
        debugPrint(e.toString());
      }
    }

    if (response != null) {
      return PamPushMessage.parse(utf8.decode(response.bodyBytes));
    }

    return null;
  }

  Future<List<PamPushMessage>?> loadPushNotificationsFromEmail(
      String email) async {
    Response? response;
    var db = Pam.shared.getDatabaseAlias();
    var contact = Pam.shared.getContactID();
    try {
      var uri = Uri.parse(
          "$baseURL/api/app-notifications?_database=$db&_contact_id=$contact&email=$email");
      response = await http.get(uri);
      if (Pam.shared.isEnableLog) {
        debugPrint("🦄🦄🦄🦄🦄 PAM LOAD PUSH NOTIFICATION 🦄🦄🦄🦄🦄🦄\n\n");
        debugPrint(uri.toString());
        debugPrint("email = $email");
        debugPrint("🚥🚥🚥🚥🚥 RESULT 🚥🚥🚥🚥🚥");
        debugPrint("Status Code: ${response.statusCode}");
        debugPrint("----- Response Body -----");
        debugPrint(utf8.decode(response.bodyBytes));
        debugPrint("\n\n🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄");
      }
    } catch (e) {
      if (Pam.shared.isEnableLog) {
        debugPrint("\n\n🦄🦄🦄🦄🦄 ERROR 🦄🦄🦄🦄🦄🦄");
        debugPrint(e.toString());
      }
    }

    if (response != null) {
      return PamPushMessage.parse(utf8.decode(response.bodyBytes));
    }

    return null;
  }

  Future<List<PamPushMessage>?> loadPushNotificationsFromCustomerID(
      String customer) async {
    Response? response;
    var db = Pam.shared.getDatabaseAlias();
    var contact = await Pam.shared.getContactID();
    try {
      var uri = Uri.parse(
          "$baseURL/api/app-notifications?_database=$db&_contact_id=$contact&customer=$customer");
      response = await http.get(uri);
      if (Pam.shared.isEnableLog) {
        debugPrint("🦄🦄🦄🦄🦄 PAM LOAD PUSH NOTIFICATION 🦄🦄🦄🦄🦄🦄\n\n");
        debugPrint(uri.toString());
        debugPrint("customer id = $customer");
        debugPrint("🚥🚥🚥🚥🚥 RESULT 🚥🚥🚥🚥🚥");
        debugPrint("Status Code: ${response.statusCode}");
        debugPrint("----- Response Body -----");
        debugPrint(utf8.decode(response.bodyBytes));
        debugPrint("\n\n🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄🦄");
      }
    } catch (e) {
      if (Pam.shared.isEnableLog) {
        debugPrint("\n\n🦄🦄🦄🦄🦄 ERROR 🦄🦄🦄🦄🦄🦄");
        debugPrint(e.toString());
      }
    }

    if (response != null) {
      return PamPushMessage.parse(utf8.decode(response.bodyBytes));
    }

    return null;
  }
}
